# UI/UX Feedback

**ID:** Feedback-20260228-230813
**URL:** http://127.0.0.1:5858
**Date:** 2026-02-28 23:10:56

## Selected Elements

- `{'selector': 'select:nth-child(2)', 'parents': ['div.modal-container', 'div.modal-body', 'div.action-context-section', 'div.context-ref-group']}`

## Feedback

base on the workflow, I finished refine action, I move on mockup action, so when I click on mockup action, it should show $output:refined-idea from refined idea as default value for context, now, there is only auto-detect option, please check the feature requirement and fix it

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260228-230813/page-screenshot.png)
